@@ -7,5 +7,6 @@ var classzypp_1_1ZYppCommitPolicy_1_1Impl =
     [ "_downloadMode", "classzypp_1_1ZYppCommitPolicy_1_1Impl.html#adcad495c98ec082d33f0edd2324e491c", null ],
     [ "_rpmInstFlags", "classzypp_1_1ZYppCommitPolicy_1_1Impl.html#ae1c9b451cbfdc5b828878ba8034530df", null ],
     [ "_syncPoolAfterCommit", "classzypp_1_1ZYppCommitPolicy_1_1Impl.html#a8b701b3f8171c1795fd5a35e067457f2", null ],
-    [ "_singleTransMode", "classzypp_1_1ZYppCommitPolicy_1_1Impl.html#add38bda1964f93032abb189e744fcd49", null ]
+    [ "_singleTransMode", "classzypp_1_1ZYppCommitPolicy_1_1Impl.html#add38bda1964f93032abb189e744fcd49", null ],
+    [ "_notifyBSC1189788", "classzypp_1_1ZYppCommitPolicy_1_1Impl.html#a775a1d74a70807d856d3e78969ec5a73", null ]
 ];
\ No newline at end of file
