@@ -123,10 +123,6 @@ var namespacezypp_1_1media =
     [ "operator<<", "namespacezypp_1_1media.html#a1650cc07e912327e0b4a3de64e46cae1", null ],
     [ "operator<<", "namespacezypp_1_1media.html#aa04d0f10b87b2000e2861cd47f76048b", null ],
     [ "operator<<", "namespacezypp_1_1media.html#ac629c95cb8382ac07d5b9047d26fa9a4", null ],
-    [ "operator<<", "namespacezypp_1_1media.html#a6f3c08fa7745b6db6e73dee9b70216b3", null ],
-    [ "operator<", "namespacezypp_1_1media.html#af70db721a39b93f6101e9fde0f9ce4ac", null ],
-    [ "operator==", "namespacezypp_1_1media.html#abed7121322cce2bcdb7606f278d65c93", null ],
-    [ "operator!=", "namespacezypp_1_1media.html#a27f1c026419dcb608b1a3f47f99fa7bb", null ],
     [ "operator<<", "namespacezypp_1_1media.html#ad30f7cc4271c75aaf758527e21680d20", null ],
     [ "operator<<", "namespacezypp_1_1media.html#a2e00dc0213ffd57140749581d1768e24", null ],
     [ "fetchnext", "namespacezypp_1_1media.html#a5e756833b1c7344b64e11041cd1384e7", null ],
