@@ -10,5 +10,6 @@ var structzypp_1_1JobReport =
     [ "warning", "structzypp_1_1JobReport.html#a5832a76ff6d1a7ff7ba3fe26188d261c", null ],
     [ "error", "structzypp_1_1JobReport.html#a67728d8b1932bfd19ecfc1e21458da99", null ],
     [ "important", "structzypp_1_1JobReport.html#ab86b0f359042fed3bbc891a866d1a2b6", null ],
-    [ "data", "structzypp_1_1JobReport.html#a943e6e2280fdb59706befb52eab5e010", null ]
+    [ "data", "structzypp_1_1JobReport.html#a943e6e2280fdb59706befb52eab5e010", null ],
+    [ "repoRefreshMirrorlist", "structzypp_1_1JobReport.html#ad5d8bd5610c6f20cd5e0e47c4e04f7f0", null ]
 ];
\ No newline at end of file
