@@ -4,8 +4,6 @@ var zypp_core_2AutoDispose_8h =
     [ "zypp::AutoDispose< Tp >::Impl", "structzypp_1_1AutoDispose_1_1Impl.html", "structzypp_1_1AutoDispose_1_1Impl" ],
     [ "zypp::AutoDispose< void >::Impl", "structzypp_1_1AutoDispose_3_01void_01_4_1_1Impl.html", "structzypp_1_1AutoDispose_3_01void_01_4_1_1Impl" ],
     [ "zypp::Deferred", "structzypp_1_1Deferred.html", "structzypp_1_1Deferred" ],
-    [ "zypp::AutoFD", "structzypp_1_1AutoFD.html", "structzypp_1_1AutoFD" ],
-    [ "zypp::AutoFILE", "structzypp_1_1AutoFILE.html", "structzypp_1_1AutoFILE" ],
     [ "zypp::AutoFREE< Tp >", "structzypp_1_1AutoFREE.html", "structzypp_1_1AutoFREE" ],
     [ "zypp::AutoFREE< void >", "structzypp_1_1AutoFREE_3_01void_01_4.html", "structzypp_1_1AutoFREE_3_01void_01_4" ],
     [ "__zypp_defer_concatenate", "zypp-core_2AutoDispose_8h.html#ad69c622837e52d846d613d3ba97a0413", null ],
